@@ -575,6 +575,8 @@ def cross():
 
 @auth.verify_password
 def verify_password(username, password):
+    global remote_ip
+    remote_ip=request.environ.get('HTTP_X_REAL_IP', request.remote_addr)
 #    user = User.query.filter_by(username = username).first()
 #    if not user or not user.verify_password(password):
 #        return False
@@ -593,12 +595,11 @@ def verify_password(username, password):
     #     print("NO FILE  ","~/.pycamfw_pass")
 
     if (username==u) and (password==p):
-        logthis( "   TRUE  checking userpass (client)"+username+"/"+password+"/")
-        logthis( "   TRUE  checking userpass (real  )"+u+"/"+p+"/")
+        # logthis( "   TRUE  checking userpass (client)"+username+"/"+password+"/")
+        logthis( f" TRUE  PASS {request.remote_addr:15s} {remote_ip:15s}: /{u}/{p}/")
         return True
     else:
-        logthis( "   FALSE checking userpass (client)"+username+"/"+password+"/")
-        logthis( "   FALSE checking userpass (real  )"+u+"/"+p+"/")
+        logthis( f" FALSE PASS {request.remote_addr:15s} {remote_ip:15s}: /{username}/{password}/")
         return False
 
 
